# src/reviewsense/core/database.py
from functools import lru_cache
from dotenv import load_dotenv
import os

from langchain_community.embeddings import HuggingFaceInferenceAPIEmbeddings
from langchain_huggingface import HuggingFaceEmbeddings
from langchain_astradb import AstraDBVectorStore

load_dotenv()
huggingface_inference_api = os.getenv("HUGGING_FACE_INTERFACE_API")
huggingface_model= os.getenv("HUGGING_FACE_MODEL")
astra_db_api_end_point=os.getenv("ASTRA_DB_API_END_POINT")
astra_db_token=os.getenv("ASTRA_DB_TOKEN")
astra_db_name_space=os.getenv("ASTRA_DB_NAME_SPACE")

@lru_cache(maxsize=1)
def get_vector_store(
    collection_name: str = "customer_reviews",
    embedding_model: str = "sentence-transformers/all-mpnet-base-v2"
):
    """
    Create a singleton vector store instance
    
    Args:
        collection_name (str): Database collection name
        embedding_model (str): Embedding model to use
    
    Returns:
        AstraDBVectorStore: Configured vector store instance
    """

    # Initialize embeddings
    embeddings = HuggingFaceInferenceAPIEmbeddings(api_key=huggingface_inference_api, model_name=huggingface_model)
    
    # Create and return vector store
    return AstraDBVectorStore(
        collection_name=collection_name,
        embedding=embeddings,
        api_endpoint=astra_db_api_end_point,
        token=astra_db_token,
        namespace=astra_db_name_space,
    )